rick_mailer - SMTP Client
--
[![Tests](https://github.com/oddbit-project/rick_mailer/workflows/Tests/badge.svg?branch=master)](https://github.com/oddbit-project/rick_mailer/actions)
[![pypi](https://img.shields.io/pypi/v/rick-mailer.svg)](https://pypi.org/project/rick-mailer/)
[![license](https://img.shields.io/pypi/l/rick-mailer.svg)](https://github.com/oddbit-project/rick_mailer/blob/master/LICENSE)


rick_mailer is a standalone version of Django's email client implementation, with minor changes. 

## License
As rick_mailer is mostly Django code, it is licensed under Django license and copyright - see the included [License file](LICENSE).


## Documentation

TBD
